import React, { useEffect } from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import { isDefault } from "../utilities/form";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import inputStyle from "design-to-code/dist/stylesheets/web-components/style/common.input.css";
import defaultFontStyle from "design-to-code/dist/stylesheets/web-components/style/common.default-font.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
import style from "./control.button.style.css";
// tree-shaking
cssVariables;
inputStyle;
defaultFontStyle;
style;
/**
 * Form control definition
 */
function ButtonControl(props) {
    function handleButtonClick() {
        return (e) => {
            e.preventDefault();
            props.onChange({ value: null });
        };
    }
    /**
     * Dummy onChange handler
     *
     * Form elements will not validate against read-only form items
     * therefore a value and onChange handler must still be supplied
     * even if there is no intention to update the value.
     */
    function handleInputChange() { }
    useEffect(() => {
        if (props.validate) {
            props.updateValidity();
            props.reportValidity();
        }
    }, [props.validate]);
    return (React.createElement(React.Fragment, null,
        React.createElement("button", { className: classNames(`dtc-button-control ${dtcClassName.commonInput}`, ["dtc-button-control__disabled", props.disabled], [
                `dtc-button-control__default ${dtcClassName.commonDefaultFont}`,
                isDefault(props.value, props.default),
            ]), ref: props.elementRef, onBlur: () => props.updateValidity(), onFocus: () => props.reportValidity(), onClick: handleButtonClick(), disabled: props.disabled }, "Set to null"),
        React.createElement("input", { id: props.dataLocation, hidden: true, value: props.value || "", onChange: handleInputChange, disabled: props.disabled })));
}
export { ButtonControl };
export default ButtonControl;
//# sourceMappingURL=control.button.js.map