import React, { useEffect } from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import { isDefault } from "../utilities/form";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import inputStyle from "design-to-code/dist/stylesheets/web-components/style/common.input.css";
import defaultFontStyle from "design-to-code/dist/stylesheets/web-components/style/common.default-font.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
import style from "./control.display.style.css";
// tree-shaking
cssVariables;
inputStyle;
defaultFontStyle;
style;
/**
 * Form control definition
 */
function DisplayControl(props) {
    /**
     * Dummy onChange handler
     *
     * Form elements will not validate against read-only form items
     * therefore a value and onChange handler must still be supplied
     * even if there is no intention to update the value.
     */
    function handleInputChange() { }
    function getDisplayValue(data) {
        const typeofData = typeof data;
        const typeofDefault = typeof props.default;
        if (typeofData === "undefined" && typeofDefault !== "undefined") {
            if (typeofDefault === "string") {
                return props.default;
            }
            return JSON.stringify(props.default, null, 2);
        }
        switch (typeofData) {
            case "string":
                return data;
            default:
                return JSON.stringify(data, null, 2);
        }
    }
    useEffect(() => {
        if (props.validate) {
            props.updateValidity();
            props.reportValidity();
        }
    }, [props.validate]);
    return (React.createElement("input", { className: classNames(`dtc-display-control ${dtcClassName.commonInput}`, ["dtc-display-control__disabled", props.disabled], [
            `dtc-display-control__default ${dtcClassName.commonDefaultFont}`,
            isDefault(props.value, props.default),
        ]), type: "text", ref: props.elementRef, onBlur: () => props.updateValidity(), onFocus: () => props.reportValidity(), value: getDisplayValue(props.value), onChange: handleInputChange, disabled: props.disabled }));
}
export { DisplayControl };
export default DisplayControl;
//# sourceMappingURL=control.display.js.map