import React, { useEffect, useState } from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import { isDefault } from "../utilities/form";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import style from "./control.textarea.style.css";
// tree-shaking
cssVariables;
style;
/**
 * Form control definition
 */
function TextareaControl(props) {
    const [focused, setFocus] = useState(false);
    function getRows() {
        return typeof props.rows === "number" ? props.rows : 3;
    }
    function getValue() {
        // Return undefined to allow typing anywhere other than the end of the string
        // when the typing is occuring in the textarea
        if (focused) {
            return;
        }
        return typeof props.value === "string"
            ? props.value
            : typeof props.default === "string"
                ? props.default
                : "";
    }
    function handleFocus(e) {
        props.reportValidity();
        setFocus(true);
    }
    function handleBlur(e) {
        props.updateValidity();
        setFocus(false);
    }
    function handleChange() {
        return (e) => {
            props.onChange({ value: e.target.value });
        };
    }
    useEffect(() => {
        if (props.validate) {
            props.updateValidity();
            props.reportValidity();
        }
    }, [props.validate]);
    return (React.createElement("textarea", { className: classNames("dtc-textarea-control", ["dtc-textarea-control__disabled", props.disabled], ["dtc-textarea-control__default", isDefault(props.value, props.default)]), id: props.dataLocation, name: props.dataLocation, rows: getRows(), value: getValue(), onChange: handleChange(), disabled: props.disabled, ref: props.elementRef, onFocus: handleFocus, onBlur: handleBlur }));
}
export { TextareaControl };
export default TextareaControl;
//# sourceMappingURL=control.textarea.js.map