import React, { useEffect, useState } from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import { isDefault } from "../utilities/form";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import style from "./control.untyped.style.css";
import { DataType } from "design-to-code";
// tree-shaking
cssVariables;
style;
/**
 * Form control definition
 */
function UntypedControl(props) {
    const [focused, setFocus] = useState(false);
    const [detectedType, setDetectedType] = useState(getType());
    useEffect(() => {
        setDetectedType(getType());
    }, [props.value]);
    useEffect(() => {
        if (props.validate) {
            props.updateValidity();
            props.reportValidity();
        }
    }, [props.validate]);
    function getType() {
        const typeofValue = typeof props.value;
        return Array.isArray(props.value)
            ? DataType.array
            : props.value === null
                ? DataType.null
                : typeofValue === "boolean"
                    ? DataType.boolean
                    : typeofValue === "undefined"
                        ? DataType.unknown
                        : typeofValue === "string"
                            ? DataType.string
                            : typeofValue === "number"
                                ? DataType.number
                                : DataType.object;
    }
    function getRows() {
        return typeof props.rows === "number" ? props.rows : 3;
    }
    function getValue() {
        // Return undefined to allow typing anywhere other than the end of the string
        // when the typing is occuring in the textarea
        if (focused) {
            return;
        }
        return typeof props.value !== "undefined"
            ? JSON.stringify(props.value, null, 2)
            : typeof props.default !== "undefined"
                ? JSON.stringify(props.default, null, 2)
                : undefined;
    }
    function handleFocus(e) {
        props.reportValidity();
        setFocus(true);
    }
    function handleBlur(e) {
        props.updateValidity();
        setFocus(false);
    }
    function handleChange() {
        return (e) => {
            const value = e.target.value;
            try {
                const parsedValue = JSON.parse(value);
                props.onChange({ value: parsedValue });
            }
            catch (e) {
                props.onChange({ value });
            }
        };
    }
    return (React.createElement("div", { className: classNames("dtc-untyped-control", ["dtc-untyped-control__disabled", props.disabled], ["dtc-untyped-control__default", isDefault(props.value, props.default)]) },
        React.createElement("div", { className: "detected-type" },
            "Detected type: ",
            React.createElement("code", null, detectedType)),
        React.createElement("textarea", { id: props.dataLocation, name: props.dataLocation, rows: getRows(), value: getValue(), onChange: handleChange(), disabled: props.disabled, ref: props.elementRef, onFocus: handleFocus, onBlur: handleBlur })));
}
export { UntypedControl };
export default UntypedControl;
//# sourceMappingURL=control.untyped.js.map