import React, { useState } from "react";
import { isPlainObject, uniqueId } from "lodash-es";
import { keyEnter } from "@microsoft/fast-web-utilities";
import { PropertyKeyword } from "design-to-code";
import ControlSwitch from "./control-switch";
import { generateExampleData, getErrorFromDataLocation } from "./form";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import controlStyle from "design-to-code/dist/stylesheets/web-components/style/common.control.css";
import labelStyle from "design-to-code/dist/stylesheets/web-components/style/common.label.css";
import controlRegionStyle from "design-to-code/dist/stylesheets/web-components/style/common.control-region.css";
import inputStyle from "design-to-code/dist/stylesheets/web-components/style/common.input.css";
import removeItemStyle from "design-to-code/dist/stylesheets/web-components/style/common.remove-item.css";
import addItemStyle from "design-to-code/dist/stylesheets/web-components/style/common.add-item.css";
import style from "./dictionary.style.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
// tree-shaking
cssVariables;
controlStyle;
labelStyle;
controlRegionStyle;
inputStyle;
removeItemStyle;
addItemStyle;
style;
/**
 *  control definition
 */
function Dictionary(props) {
    const rootElementRef = React.createRef();
    const [focusedPropertyKey, setFocusedPropertyKey] = useState(null);
    const [focusedPropertyKeyValue, setFocusedPropertyKeyValue] = useState(null);
    function updateValidity() {
        if (props.additionalProperties === false) {
            rootElementRef.current
                .querySelectorAll(`.${`dtc-dictionary_item-control-input ${dtcClassName.commonInput}`}`)
                .forEach((itemControlInput) => {
                itemControlInput.setCustomValidity("should NOT have additional properties");
            });
        }
    }
    function renderControl() {
        if (isPlainObject(props.additionalProperties)) {
            return (React.createElement("div", { className: `dtc-dictionary_control-region ${dtcClassName.commonControlRegion}` },
                React.createElement("div", { className: `dtc-dictionary_control` },
                    React.createElement("label", { className: `dtc-dictionary_control-label ${dtcClassName.commonLabel}` }, props.label)),
                React.createElement("button", { className: `dtc-dictionary_control-add-trigger ${dtcClassName.commonAddItem}`, "aria-label": "Select to add item", onClick: handleOnAddItem })));
        }
    }
    function renderItemControl(propertyName) {
        return (React.createElement("div", { className: `dtc-dictionary_item-control-region ${dtcClassName.commonControlRegion}` },
            React.createElement("div", { className: `dtc-dictionary_item-control` },
                React.createElement("label", { className: `dtc-dictionary_item-control-label ${dtcClassName.commonLabel}` }, props.propertyLabel),
                React.createElement("input", { className: `dtc-dictionary_item-control-input ${dtcClassName.commonInput}`, type: "text", value: focusedPropertyKey === propertyName
                        ? focusedPropertyKeyValue
                        : propertyName, onFocus: handleKeyFocus(propertyName), onBlur: handleKeyBlur(propertyName), onKeyDown: handleKeyPress(), onChange: handleKeyChange(propertyName), readOnly: props.additionalProperties === false }),
                React.createElement("button", { className: `dtc-dictionary_item-control-remove-trigger ${dtcClassName.commonRemoveItem}`, onClick: handleOnRemoveItem(propertyName) }))));
    }
    function renderControls() {
        return (typeof props.data !== "undefined" ? Object.keys(props.data) : []).reduce((accumulator, currentKey, index) => {
            if (!props.enumeratedProperties.includes(currentKey)) {
                const dataLocation = getDataLocation(currentKey);
                const invalidMessage = getErrorFromDataLocation(dataLocation, props.validationErrors);
                return (React.createElement(React.Fragment, { key: dataLocation },
                    accumulator,
                    React.createElement("div", { key: props.schemaLocation + index },
                        renderItemControl(currentKey),
                        React.createElement(ControlSwitch, { index: index, controls: props.controls, controlPlugins: props.controlPlugins, controlComponents: props.controlComponents, label: props.label, onChange: props.onChange, propertyName: currentKey, schemaLocation: getSchemaLocation(currentKey), dataLocation: dataLocation, data: getData(currentKey), schema: props.additionalProperties, disabled: props.additionalProperties === false, onUpdateSection: props.onUpdateSection, required: isRequired(currentKey), invalidMessage: invalidMessage, remove: false, displayValidationInline: props.displayValidationInline, displayValidationBrowserDefault: props.displayValidationBrowserDefault, strings: props.strings, type: props.type, categories: props.categories, untitled: props.untitled, dictionaryId: props.dictionaryId, dataDictionary: props.dataDictionary, navigation: props.navigation, navigationConfigId: props.navigationConfigId, validationErrors: props.validationErrors, schemaDictionary: props.schemaDictionary, messageSystem: props.messageSystem, messageSystemOptions: props.messageSystemOptions, validate: props.validate }))));
            }
            return accumulator;
        }, null);
    }
    function handleOnAddItem(e) {
        const key = uniqueId("example");
        if (typeof props.default !== "undefined") {
            props.onChange({
                dataLocation: `${props.dataLocation === "" ? "" : `${props.dataLocation}.`}${key}`,
                dictionaryId: props.dictionaryId,
                value: props.default,
            });
        }
        else if (Array.isArray(props.examples) && props.examples.length > 0) {
            props.onChange({
                dataLocation: `${props.dataLocation === "" ? "" : `${props.dataLocation}.`}${key}`,
                dictionaryId: props.dictionaryId,
                value: props.examples[0],
            });
        }
        else {
            props.onChange({
                dataLocation: `${props.dataLocation === "" ? "" : `${props.dataLocation}.`}${key}`,
                dictionaryId: props.dictionaryId,
                value: generateExampleData(props.schemaDictionary[props.dataDictionary[0][props.dictionaryId].schemaId], props.additionalProperties, ""),
            });
        }
    }
    function handleOnRemoveItem(propertyName) {
        return (e) => {
            props.onChange({
                dataLocation: `${props.dataLocation === "" ? "" : `${props.dataLocation}.`}${propertyName}`,
                dictionaryId: props.dictionaryId,
                value: void 0,
            });
        };
    }
    function handleKeyPress() {
        return (e) => {
            if (e.key === keyEnter) {
                e.currentTarget.blur();
                e.preventDefault();
            }
        };
    }
    function handleKeyChange(propertyName) {
        return (e) => {
            setFocusedPropertyKeyValue(e.target.value);
        };
    }
    function handleKeyFocus(propertyName) {
        return (e) => {
            setFocusedPropertyKey(propertyName);
            setFocusedPropertyKeyValue(propertyName);
        };
    }
    function handleKeyBlur(propertyName) {
        return (e) => {
            const dataKeys = typeof props.data === "undefined" ? [] : Object.keys(props.data);
            const data = {};
            dataKeys.forEach((dataKey) => {
                data[dataKey === propertyName ? e.target.value : dataKey] =
                    props.data[dataKey];
            });
            props.onChange({
                dataLocation: props.dataLocation,
                dictionaryId: props.dictionaryId,
                value: data,
            });
            setFocusedPropertyKey(null);
            setFocusedPropertyKeyValue(null);
        };
    }
    function getSchemaLocation(propertyName) {
        return `${props.schemaLocation === "" ? "" : `${props.schemaLocation}.`}${PropertyKeyword.additionalProperties}.${propertyName}`;
    }
    function getDataLocation(propertyName) {
        return `${props.dataLocation}${props.dataLocation !== "" ? "." : ""}${propertyName}`;
    }
    function getData(propertyName) {
        return props.data[propertyName];
    }
    function isRequired(propertyName) {
        return Array.isArray(props.required) && props.required.includes(propertyName);
    }
    return (React.createElement("div", { className: "dtc-dictionary", ref: rootElementRef },
        renderControl(),
        renderControls()));
}
export { Dictionary };
export default Dictionary;
//# sourceMappingURL=dictionary.js.map