import React from "react";
import { Alignment } from "./control.align.props";
import { classNames } from "@microsoft/fast-web-utilities";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
import alignStyle from "./control.align.style.css";
// tree-shaking
cssVariables;
alignStyle;
/**
 * Custom form control definition
 */
function AlignControl(props) {
    function isChecked(direction) {
        return (props.value === direction ||
            (typeof props.value === "undefined" && props.default === direction));
    }
    function handleChange(value) {
        return () => {
            props.onChange({ value });
        };
    }
    function renderInput(direction) {
        if (props.options && Array.isArray(props.options)) {
            const option = props.options.find((item) => {
                return item === direction;
            });
            if (typeof option !== "undefined") {
                return (React.createElement("span", null,
                    React.createElement("input", { className: classNames(`dtc-align-control_input ${dtcClassName.commonInputBackplate}`, [
                            "dtc-align-control_input__bottom",
                            direction === Alignment.bottom,
                        ], [
                            "dtc-align-control_input__center",
                            direction === Alignment.center,
                        ], [
                            "dtc-align-control_input__top",
                            direction === Alignment.top,
                        ]), id: props.dataLocation, type: "radio", value: direction, name: props.dataLocation, "aria-label": `${direction} align`, onChange: handleChange(direction), checked: isChecked(direction), disabled: props.disabled })));
            }
        }
    }
    return (React.createElement("div", { className: classNames("dtc-align-control", [
            "dtc-align-control__disabled",
            props.disabled,
        ]) },
        renderInput(Alignment.top),
        renderInput(Alignment.center),
        renderInput(Alignment.bottom)));
}
export { AlignControl };
export default AlignControl;
//# sourceMappingURL=control.align.js.map