/** @jsx h */ /* Note: Set the JSX pragma to the wrapped version of createElement */
import h from "../../utilities/web-components/pragma"; /* Note: Import wrapped createElement. */
import React from "react";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
export function renderDefault(config) {
    return renderTextInput(config);
}
function getInputChangeHandler(parentChangeHandler) {
    let timer = null;
    const handleCheck = (newValue) => {
        clearTimeout(timer);
        timer = setTimeout(() => {
            parentChangeHandler(newValue);
        }, 500);
    };
    return (e) => {
        handleCheck(e.currentTarget.value);
    };
}
// TODO: is there a better way to retrieve design system context and use the tagFor?
// this is currently an experimental component however this should be adjusted before
// documentation and export
export function renderTextInput(config) {
    return (h("input", Object.assign({ type: "text", className: "dtc-textarea-control" }, Object.assign({ key: `${config.dictionaryId}::${config.dataLocation}`, events: {
            input: getInputChangeHandler(config.handleChange),
        } }, (config.value
        ? {
            value: config.value,
        }
        : {})))));
}
export function renderNumber(config) {
    return (h("input", Object.assign({ type: "number", className: `dtc-number-field-control ${dtcClassName.commonInput}` }, Object.assign({ key: `${config.dictionaryId}::${config.dataLocation}`, events: {
            input: getInputChangeHandler(config.handleChange),
        } }, (config.value
        ? {
            value: config.value,
        }
        : {})))));
}
export function renderInteger(config) {
    return (h("input", Object.assign({ type: "number", className: `dtc-number-field-control ${dtcClassName.commonInput}` }, Object.assign({ key: `${config.dictionaryId}::${config.dataLocation}`, events: {
            input: getInputChangeHandler(config.handleChange),
        }, step: 1 }, (config.value
        ? {
            value: config.value,
        }
        : {})))));
}
function getCheckboxInputChangeHandler(parentChangeHandler, value) {
    return (e) => {
        parentChangeHandler(e.currentTarget.checked ? value : "");
    };
}
export function renderCheckbox(config) {
    return (h(React.Fragment, null,
        h("input", Object.assign({ type: "checkbox", className: "dtc-checkbox-control" }, Object.assign({ events: {
                change: getCheckboxInputChangeHandler(config.handleChange, config.ref.ref),
            } }, (config.value
            ? {
                value: config.value,
            }
            : {})))),
        h("span", { className: "dtc-checkbox-control_checkmark" }),
        h("label", null, config.ref.ref)));
}
function getSelectionChangeHandler(parentChangeHandler) {
    return (e) => {
        parentChangeHandler(e.currentTarget.value);
    };
}
export function renderSelection(config) {
    const currentOption = config.options.find(option => option.displayName === config.value);
    const currentValue = currentOption ? `${currentOption.value}` : "";
    return (h("span", { className: dtcClassName.commonSelectSpan },
        h("select", { className: `dtc-select-control_input ${dtcClassName.commonSelectInput}`, key: `${config.dictionaryId}::${config.dataLocation}`, onChange: getSelectionChangeHandler(config.handleChange), value: currentValue }, config.options.map(option => {
            return (h("option", Object.assign({}, {
                value: `${option.value}`,
                key: `${config.dictionaryId}::${config.dataLocation}::${option.key}`,
            }), option.displayName));
        }))));
}
function getColorPickerChangeHandler(parentChangeHandler) {
    let timer = null;
    const handleCheck = (newValue) => {
        clearTimeout(timer);
        timer = setTimeout(() => {
            parentChangeHandler(newValue);
        }, 500);
    };
    return (e) => {
        handleCheck(e.currentTarget.value);
    };
}
export function renderColorPicker(config) {
    return (h("dtc-color-picker", { key: `${config.dictionaryId}::${config.dataLocation}`, value: config.value, events: {
            change: getColorPickerChangeHandler(config.handleChange),
        }, "control-text-field-stylesheet": config.stylesheets.controlTextFieldStylesheet, "common-input-stylesheet": config.stylesheets.commonInputStylesheet, "common-default-font-stylesheet": config.stylesheets.commonDefaultFontStylesheet }));
}
//# sourceMappingURL=control.css.utilities.js.map