import React from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
import textAlignStyle from "./control.text-align.style.css";
// tree-shaking
cssVariables;
textAlignStyle;
var Direction;
(function (Direction) {
    Direction["Left"] = "left";
    Direction["Center"] = "center";
    Direction["Right"] = "right";
    Direction["Justify"] = "justify";
})(Direction || (Direction = {}));
/**
 * Custom form control definition
 */
function TextAlignControl(props) {
    function onChange(value) {
        props.onChange({ value });
    }
    function isChecked(direction) {
        return (props.value === direction ||
            (typeof props.value === "undefined" && props.default === direction));
    }
    function getInputClassName(direction) {
        switch (direction) {
            case Direction.Left:
                return "dtc-text-align-control_input__left";
            case Direction.Center:
                return "dtc-text-align-control_input__center";
            case Direction.Right:
                return "dtc-text-align-control_input__right";
            case Direction.Justify:
                return "dtc-text-align-control_input__justify";
        }
    }
    function getDirectionLabel(direction) {
        switch (direction) {
            case Direction.Left:
                return props.strings.textAlignLeftLabel;
            case Direction.Center:
                return props.strings.textAlignCenterLabel;
            case Direction.Right:
                return props.strings.textAlignRightLabel;
            case Direction.Justify:
                return props.strings.textAlignJustifyLabel;
        }
    }
    function renderInput(direction) {
        if (props.options && Array.isArray(props.options)) {
            const option = props.options.find((item) => {
                return item === direction;
            });
            if (typeof option !== "undefined") {
                return (React.createElement("span", null,
                    React.createElement("input", { className: classNames(`dtc-text-align-control_input ${dtcClassName.commonInputBackplate}`, getInputClassName(direction)), id: props.dataLocation, type: "radio", value: direction, name: props.dataLocation, "aria-label": getDirectionLabel(direction), onChange: onChange.bind(this, direction), checked: isChecked(direction), disabled: props.disabled })));
            }
        }
    }
    return (React.createElement("div", { className: classNames("dtc-text-align-control", [
            "dtc-text-align-control__disabled",
            props.disabled,
        ]) },
        renderInput(Direction.Left),
        renderInput(Direction.Center),
        renderInput(Direction.Right),
        renderInput(Direction.Justify)));
}
export { TextAlignControl };
export default TextAlignControl;
//# sourceMappingURL=control.text-align.js.map