import React, { useEffect, useState } from "react";
import { keyArrowDown, keyArrowLeft, keyArrowRight, keyArrowUp, keyEnd, keyEnter, keyHome, keySpace, } from "@microsoft/fast-web-utilities";
import { get } from "lodash-es";
import { canUseDOM } from "exenv-es6";
// import { DraggableNavigationTreeItem } from "./navigation-tree-item";
import { NavigationTreeItem } from "./navigation-tree-item";
import { DragDropItemType } from "./navigation-tree-item.props";
import { dataSetName, dictionaryLink, MessageSystemDataTypeAction, MessageSystemNavigationTypeAction, MessageSystemType, DataType, } from "design-to-code";
import { getDraggableItemClassName, getDragStartMessage, getDragStartState, getDragEndMessage, getDragHoverState, isActiveItem, } from "./navigation.utilities";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import inputStyle from "design-to-code/dist/stylesheets/web-components/style/common.input.css";
import ellipsisStyle from "design-to-code/dist/stylesheets/web-components/style/common.ellipsis.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
import style from "./navigation.style.css";
// tree-shaking
cssVariables;
inputStyle;
ellipsisStyle;
style;
export const navigationId = "dtc-react::navigation";
function Navigation(props) {
    const messageSystemConfig = {
        onMessage: handleMessageSystem,
        config: {
            displayTextDataLocation: dataSetName,
        },
    };
    const rootElement = React.createRef();
    const editableElement = React.createRef();
    const activeItem = React.createRef();
    const [navigationDictionary, setNavigationDictionary] = useState(null);
    const [dataDictionary, setDataDictionary] = useState(null);
    const [activeDictionaryId, setActiveDictionaryId] = useState("");
    const [activeNavigationConfigId, setActiveNavigationConfigId] = useState("");
    const [textEditing, setTextEditing] = useState(null);
    const [expandedNavigationConfigItems, setExpandedNavigationConfigItems] = useState({});
    const [linkedData, setLinkedData] = useState(void 0);
    const [linkedDataLocation, setLinkedDataLocation] = useState(null);
    const [hoveredItem, setHoveredItem] = useState(null);
    useEffect(() => {
        if (props.messageSystem !== undefined) {
            props.messageSystem.add(messageSystemConfig);
        }
        return function cancel() {
            if (props.messageSystem !== undefined) {
                props.messageSystem.remove(messageSystemConfig);
            }
        };
    });
    function getActiveConfigIds(activeDictionaryId, activeNavigationConfigId) {
        const updatedDictionaryItemConfigItems = new Set(expandedNavigationConfigItems[activeDictionaryId]);
        if (expandedNavigationConfigItems[activeDictionaryId] === undefined) {
            return new Set([activeNavigationConfigId]);
        }
        else if (updatedDictionaryItemConfigItems.has(activeNavigationConfigId)) {
            updatedDictionaryItemConfigItems.delete(activeNavigationConfigId);
            return updatedDictionaryItemConfigItems;
        }
        updatedDictionaryItemConfigItems.add(activeNavigationConfigId);
        return updatedDictionaryItemConfigItems;
    }
    function scrollActiveItemIntoView(e) {
        var _a, _b;
        if (props.scrollIntoView &&
            ((_a = e.data.options) === null || _a === void 0 ? void 0 : _a.originatorId) !== navigationId &&
            e.data.activeDictionaryId) {
            (_b = activeItem === null || activeItem === void 0 ? void 0 : activeItem.current) === null || _b === void 0 ? void 0 : _b.scrollIntoView({
                block: "center",
                inline: "center",
                behavior: "smooth",
            });
        }
    }
    /**
     * Handle messages from the message system
     */
    function handleMessageSystem(e) {
        let updatedActiveDictionaryId = e.data.activeDictionaryId;
        let updatedActiveNavigationConfigId = e.data.activeNavigationConfigId;
        let updatedDataDictionary = e.data.dataDictionary;
        let updatedNavigationDictionary = e.data.navigationDictionary;
        let updatedExpandedNavigationConfigItems = expandedNavigationConfigItems;
        let setState = false;
        switch (e.data.type) {
            case MessageSystemType.initialize:
                updatedActiveDictionaryId = e.data.activeDictionaryId
                    ? e.data.activeDictionaryId
                    : e.data.navigationDictionary[1];
                updatedActiveNavigationConfigId = e.data.activeNavigationConfigId
                    ? e.data.activeNavigationConfigId
                    : e.data.navigationDictionary[0][e.data.navigationDictionary[1]][1];
                setState = true;
                break;
            case MessageSystemType.data:
                updatedActiveDictionaryId = e.data.activeDictionaryId
                    ? e.data.activeDictionaryId
                    : activeDictionaryId;
                updatedActiveNavigationConfigId = e.data.activeNavigationConfigId
                    ? e.data.activeNavigationConfigId
                    : activeNavigationConfigId;
                setState = true;
                break;
            case MessageSystemType.navigation:
                updatedExpandedNavigationConfigItems = getUpdatedElementsExpanded(e.data.activeDictionaryId, e.data.activeNavigationConfigId);
                setState = true;
                break;
        }
        if (setState) {
            setActiveDictionaryId(updatedActiveDictionaryId);
            setActiveNavigationConfigId(updatedActiveNavigationConfigId);
            setDataDictionary(updatedDataDictionary);
            setExpandedNavigationConfigItems(updatedExpandedNavigationConfigItems);
            setNavigationDictionary(updatedNavigationDictionary);
            scrollActiveItemIntoView.bind(this, e);
        }
    }
    function renderDictionaryItem(dictionaryId, index) {
        if (dictionaryId !== null) {
            return renderNavigationConfig(dictionaryId, navigationDictionary[0][dictionaryId][1], index);
        }
        return null;
    }
    function renderNavigationConfig(dictionaryId, navigationConfigId, index) {
        var _a, _b, _c, _d, _e;
        const schema = (_d = (_c = (_b = (_a = navigationDictionary[0]) === null || _a === void 0 ? void 0 : _a[dictionaryId]) === null || _b === void 0 ? void 0 : _b[0]) === null || _c === void 0 ? void 0 : _c[navigationConfigId]) === null || _d === void 0 ? void 0 : _d.schema;
        const isLinkedData = navigationDictionary[0][dictionaryId] !== undefined &&
            navigationDictionary[0][dictionaryId][1] === navigationConfigId;
        const isRootLinkedData = navigationDictionary[1] === dictionaryId && navigationConfigId === "";
        const isDraggable = isLinkedData && !isRootLinkedData; // is linked data and not the root level item
        const isBlockedFromBeingDroppable = !(((_e = props === null || props === void 0 ? void 0 : props.droppableBlocklist) === null || _e === void 0 ? void 0 : _e.includes(schema === null || schema === void 0 ? void 0 : schema.$id)) || false); // is included in the droppable blocked list provided
        const isDroppable = isBlockedFromBeingDroppable &&
            ((isLinkedData && (schema === null || schema === void 0 ? void 0 : schema.type) === DataType.object && !isRootLinkedData) || // a piece of linked data that is not the root and is an object type
                (schema === null || schema === void 0 ? void 0 : schema[dictionaryLink]) || // an identified dictionary link
                (isRootLinkedData && props.defaultLinkedDataDroppableDataLocation)); // the root linked data with an defined droppable data location
        const isTriggerRenderable = shouldTriggerRender(dictionaryId, navigationConfigId);
        const content = renderContent(dictionaryId, navigationConfigId, isTriggerRenderable);
        const itemType = isRootLinkedData && isDroppable
            ? DragDropItemType.rootLinkedData
            : isRootLinkedData
                ? DragDropItemType.rootLinkedDataUndroppable
                : isLinkedData && isDroppable
                    ? DragDropItemType.linkedData
                    : isLinkedData
                        ? DragDropItemType.linkedDataUndroppable
                        : isDroppable
                            ? DragDropItemType.linkedDataContainer
                            : DragDropItemType.undraggableUndroppable;
        const trigger = isTriggerRenderable
            ? renderTrigger(itemType, navigationDictionary[0][dictionaryId][0][navigationConfigId].text, content !== null, isDraggable, itemType !== DragDropItemType.undraggableUndroppable, dictionaryId, navigationConfigId, index)
            : null;
        if (trigger === null && content === null) {
            return null;
        }
        return (React.createElement("div", { role: "treeitem", className: "dtc-navigation_item-region", "aria-expanded": getExpandedState(dictionaryId, navigationConfigId), "data-type": itemType, key: index },
            trigger,
            content));
    }
    function renderTrigger(type, text, isCollapsible, isDraggable, isDroppable, dictionaryId, navigationConfigId, index) {
        return (React.createElement(NavigationTreeItem, { type: type, index: index, key: index, isCollapsible: isCollapsible, isEditing: isEditing(dictionaryId, navigationConfigId), inputRef: editableElement, itemRef: isActiveItem(activeDictionaryId, dictionaryId, activeNavigationConfigId, navigationConfigId)
                ? activeItem
                : null, className: getDraggableItemClassName(isCollapsible, isDraggable, isDroppable, dictionaryId, navigationConfigId, hoveredItem, activeDictionaryId, activeNavigationConfigId, props.defaultLinkedDataDroppableDataLocation, "dtc-navigation_item", "dtc-navigation_item__expandable", "dtc-navigation_item__active", "dtc-navigation_item__draggable", "dtc-navigation_item__droppable", "dtc-navigation_item__hover", "dtc-navigation_item__hover-after", "dtc-navigation_item__hover-before"), expandTriggerClassName: "dtc-navigation_item-expand-trigger", contentClassName: "dtc-navigation_item-content", displayTextInputClassName: `dtc-navigation_item-display-text-input ${dtcClassName.commonInput}`, handleExpandClick: handleNavigationItemExpandClick(dictionaryId, navigationConfigId), handleClick: handleNavigationItemClick(dictionaryId, navigationConfigId), handleInputChange: handleNavigationItemChangeDisplayText(dictionaryId), handleInputBlur: handleNavigationItemBlurDisplayTextInput(), handleInputKeyDown: handleNavigationItemKeyDownDisplayTextInput(), handleKeyDown: handleNavigationItemKeyDown(dictionaryId, navigationConfigId), dictionaryId: dictionaryId, navigationConfigId: navigationConfigId, dragStart: handleDragStart(index), dragEnd: handleDragEnd, dragHover: handleDragHover, text: text }));
    }
    function renderContent(dictionaryId, navigationConfigId, isTriggerRendered) {
        const navigationConfig = navigationDictionary[0][dictionaryId][0][navigationConfigId];
        if (Array.isArray(navigationConfig.items) && navigationConfig.items.length > 0) {
            const content = navigationConfig.items.map((navigationConfigItemId, index) => {
                if (navigationConfig.schema[dictionaryLink] &&
                    Array.isArray(navigationConfig.data) &&
                    navigationConfig.data[index]) {
                    return renderDictionaryItem(navigationConfig.data[index].id, index);
                }
                return renderNavigationConfig(dictionaryId, navigationConfigItemId, index);
            });
            const isEmpty = content.find((contentItem) => {
                return contentItem !== null;
            }) === undefined;
            if (!isEmpty) {
                if (isTriggerRendered) {
                    return (React.createElement("div", { role: "group", key: "content", className: "dtc-navigation_item-list" }, content));
                }
                return content;
            }
        }
        return null;
    }
    /**
     * Determine if an element is currently being edited
     */
    function isEditing(dictionaryId, navigationConfigId) {
        return (textEditing &&
            textEditing.dictionaryId === dictionaryId &&
            textEditing.navigationConfigId === navigationConfigId &&
            textEditing.navigationConfigId === "");
    }
    function shouldTriggerRender(dictionaryId, navigationConfigId) {
        return (!Array.isArray(props.types) ||
            props.types.includes(navigationDictionary[0][dictionaryId][0][navigationConfigId].type));
    }
    function getExpandedState(dictionaryId, navigationConfigId) {
        // assume this is the root level tree item if these are undefined
        if (dictionaryId === undefined && navigationConfigId === undefined) {
            if (navigationDictionary === null) {
                return false;
            }
            return (expandedNavigationConfigItems[navigationDictionary[1]] !== undefined &&
                expandedNavigationConfigItems[navigationDictionary[1]].has(navigationDictionary[0][navigationDictionary[1]][1]));
        }
        return (expandedNavigationConfigItems[dictionaryId] !== undefined &&
            expandedNavigationConfigItems[dictionaryId].has(navigationConfigId));
    }
    function getUpdatedElementsExpanded(dictionaryId, navigationConfigId) {
        return Object.assign(Object.assign({}, expandedNavigationConfigItems), getParentElement(dictionaryId));
    }
    function getParentElement(dictionaryId) {
        if (dataDictionary[0][dictionaryId].parent) {
            const parentDictionaryId = dataDictionary[0][dictionaryId].parent.id;
            const parentDictionaryItem = expandedNavigationConfigItems[parentDictionaryId]
                ? new Set(["", ...expandedNavigationConfigItems[parentDictionaryId]])
                : new Set([""]);
            const parentDictionaryItemDataLocations = new Set(dataDictionary[0][dictionaryId].parent.dataLocation.split("."));
            return Object.assign({ [parentDictionaryId]: new Set([
                    ...parentDictionaryItemDataLocations,
                    ...parentDictionaryItem,
                ]) }, getParentElement(parentDictionaryId));
        }
        return {};
    }
    /**
     * Handler for the beginning of the drag
     * - This method removes the dragging item from the data
     */
    function handleDragStart(index) {
        return (dictionaryId, type) => {
            const dragStartState = getDragStartState(dictionaryId, index, dataDictionary, navigationDictionary);
            setLinkedData(dragStartState.linkedData);
            setLinkedDataLocation(dragStartState.linkedDataLocation);
            props.messageSystem.postMessage(getDragStartMessage(dictionaryId, navigationId, navigationDictionary));
            return {
                type,
            };
        };
    }
    function handleDragEnd() {
        props.messageSystem.postMessage(getDragEndMessage(navigationId, hoveredItem, linkedData, linkedDataLocation, props.defaultLinkedDataDroppableDataLocation));
        setHoveredItem(null);
    }
    /**
     * Handles hovering over an item
     */
    function handleDragHover(type, dictionaryId, navigationConfigId, index, location) {
        const dragHoverState = getDragHoverState(dictionaryId, navigationConfigId, type, location, index, hoveredItem, navigationDictionary, props.defaultLinkedDataDroppableDataLocation);
        setHoveredItem(dragHoverState.hoveredItem);
        setLinkedDataLocation(dragHoverState.linkedDataLocation);
    }
    /**
     * Handle clicks on a navigation item
     */
    function handleNavigationItemClick(dictionaryId, navigationConfigId) {
        let timer;
        let timesClicked = 0;
        return (event) => {
            timesClicked += 1;
            setTimeout(() => {
                if (timesClicked === 1) {
                    handleNavigationItemSingleClick(dictionaryId, navigationConfigId);
                    clearTimeout(timer);
                }
                else if (timesClicked === 2) {
                    handleNavigationItemDoubleClick(dictionaryId, navigationConfigId);
                    clearTimeout(timer);
                }
                timesClicked = 0;
            }, 200);
        };
    }
    /**
     * Update the active item
     */
    function handleNavigationItemSingleClick(dictionaryId, navigationConfigId) {
        triggerNavigationUpdate(dictionaryId, navigationConfigId);
    }
    /**
     * Allows editing of the active item
     */
    function handleNavigationItemDoubleClick(dictionaryId, navigationConfigId) {
        triggerNavigationEdit(dictionaryId, navigationConfigId);
    }
    /**
     * Update the active items display text
     */
    function handleNavigationItemChangeDisplayText(dictionaryId) {
        return (e) => {
            props.messageSystem.postMessage({
                type: MessageSystemType.data,
                action: MessageSystemDataTypeAction.update,
                dictionaryId,
                dataLocation: dataSetName,
                data: e.target.value,
                options: {
                    originatorId: navigationId,
                },
            });
        };
    }
    /**
     * Update the active items display text focus state
     */
    function handleNavigationItemBlurDisplayTextInput() {
        return () => {
            setTextEditing(null);
        };
    }
    /**
     * Handles key up on the active items display text
     */
    function handleNavigationItemKeyDownDisplayTextInput() {
        return (e) => {
            if (e.target === e.currentTarget) {
                switch (e.key) {
                    case keyEnter:
                        setTextEditing(null);
                }
            }
        };
    }
    /**
     * Update an items expandable state
     */
    function handleNavigationItemExpandClick(dictionaryId, navigationConfigId) {
        return () => {
            triggerExpandCollapse(dictionaryId, navigationConfigId);
        };
    }
    function triggerExpandCollapse(dictionaryId, navigationConfigId) {
        setExpandedNavigationConfigItems(Object.assign(Object.assign({}, expandedNavigationConfigItems), { [dictionaryId]: getActiveConfigIds(dictionaryId, navigationConfigId) }));
    }
    function triggerNavigationEdit(dictionaryId, navigationConfigId) {
        setTextEditing({
            dictionaryId,
            navigationConfigId,
        });
        if (editableElement === null || editableElement === void 0 ? void 0 : editableElement.current) {
            editableElement.current.focus();
            editableElement.current.select();
        }
    }
    function triggerNavigationUpdate(dictionaryId, navigationConfigId) {
        setTextEditing(null);
        props.messageSystem.postMessage({
            type: MessageSystemType.navigation,
            action: MessageSystemNavigationTypeAction.update,
            activeDictionaryId: dictionaryId,
            activeNavigationConfigId: navigationConfigId,
            options: {
                originatorId: navigationId,
            },
        });
    }
    function findCurrentTreeItemIndex(nodes, dictionaryId, navigationConfigId) {
        return nodes.findIndex((node) => {
            return (node.dataset.dictionaryid === dictionaryId &&
                node.dataset.navigationconfigid === navigationConfigId);
        });
    }
    function focusNextTreeItem(dictionaryId, navigationConfigId) {
        if (canUseDOM()) {
            const nodes = getTreeItemNodes();
            const currentIndex = findCurrentTreeItemIndex(nodes, dictionaryId, navigationConfigId);
            const nextIndex = currentIndex !== -1 && currentIndex !== nodes.length - 1
                ? currentIndex + 1
                : nodes.length - 1;
            nodes[nextIndex].focus();
        }
    }
    function focusPreviousTreeItem(dictionaryId, navigationConfigId) {
        if (canUseDOM()) {
            const nodes = getTreeItemNodes();
            const currentIndex = findCurrentTreeItemIndex(nodes, dictionaryId, navigationConfigId);
            const previousIndex = currentIndex !== -1 && currentIndex !== 0 ? currentIndex - 1 : 0;
            nodes[previousIndex].focus();
        }
    }
    function focusFirstTreeItem() {
        if (canUseDOM()) {
            const nodes = getTreeItemNodes();
            nodes[0].focus();
        }
    }
    function focusLastTreeItem() {
        if (canUseDOM()) {
            const nodes = getTreeItemNodes();
            nodes[nodes.length - 1].focus();
        }
    }
    function focusAndOpenTreeItems(dictionaryId, navigationConfigId) {
        if (canUseDOM()) {
            const nodes = getTreeItemNodes();
            const currentIndex = findCurrentTreeItemIndex(nodes, dictionaryId, navigationConfigId);
            const ariaExpanded = get(nodes[currentIndex], 'parentElement.parentElement.attributes["aria-expanded"].value');
            if (nodes[currentIndex].tagName !== "A" &&
                ariaExpanded === "true" &&
                nodes[currentIndex + 1]) {
                nodes[currentIndex + 1].focus();
            }
            else if (ariaExpanded === "false") {
                triggerExpandCollapse(dictionaryId, navigationConfigId);
                triggerNavigationUpdate(dictionaryId, navigationConfigId);
            }
        }
    }
    function focusAndCloseTreeItems(dictionaryId, navigationConfigId) {
        if (canUseDOM()) {
            const nodes = getTreeItemNodes();
            const currentIndex = findCurrentTreeItemIndex(nodes, dictionaryId, navigationConfigId);
            const ariaExpanded = get(nodes[currentIndex], 'parentElement.parentElement.attributes["aria-expanded"].value');
            if (nodes[currentIndex].tagName === "A") {
                const parent = get(nodes[currentIndex], "parentElement.parentElement.parentElement.parentElement.firstChild");
                if (parent) {
                    parent.querySelector("[data-dictionaryid]").focus();
                }
            }
            else if (ariaExpanded === "false" && nodes[currentIndex - 1]) {
                nodes[currentIndex - 1].focus();
            }
            else if (ariaExpanded === "true") {
                triggerExpandCollapse(dictionaryId, navigationConfigId);
                triggerNavigationUpdate(dictionaryId, navigationConfigId);
            }
        }
    }
    function getTreeItemNodes() {
        const nodes = Array.from(rootElement.current.querySelectorAll("div[role='treeitem'] > a, div[role='treeitem'] > span > [data-dictionaryid]"));
        return nodes.filter((node) => node.offsetParent !== null);
    }
    /**
     * Handles key up on a tree item
     */
    function handleNavigationItemKeyDown(dictionaryId, navigationConfigId) {
        return (e) => {
            e.preventDefault();
            if (e.target === e.currentTarget) {
                switch (e.key) {
                    case keyEnter:
                    case keySpace:
                        if (e.target === e.currentTarget) {
                            triggerExpandCollapse(dictionaryId, navigationConfigId);
                            triggerNavigationUpdate(dictionaryId, navigationConfigId);
                        }
                        break;
                    case keyArrowDown:
                        focusNextTreeItem(dictionaryId, navigationConfigId);
                        break;
                    case keyArrowUp:
                        focusPreviousTreeItem(dictionaryId, navigationConfigId);
                        break;
                    case keyArrowRight:
                        focusAndOpenTreeItems(dictionaryId, navigationConfigId);
                        break;
                    case keyArrowLeft:
                        focusAndCloseTreeItems(dictionaryId, navigationConfigId);
                        break;
                    case keyHome:
                        focusFirstTreeItem();
                        break;
                    case keyEnd:
                        focusLastTreeItem();
                        break;
                }
            }
        };
    }
    return (React.createElement("div", { ref: rootElement, role: "tree", className: "dtc-navigation" },
        React.createElement("div", { role: "treeitem", className: `dtc-navigation_item ${dtcClassName.commonEllipsis}`, "aria-expanded": getExpandedState() }, renderDictionaryItem(navigationDictionary !== null ? navigationDictionary[1] : null, 0))));
}
export { Navigation };
export default Navigation;
//# sourceMappingURL=navigation.js.map